@@ -7,7 +7,7 @@
 #  define VTKFILTERSREEBGRAPH_NO_EXPORT
 #else
 #  ifndef VTKFILTERSREEBGRAPH_EXPORT
-#    ifdef vtkFiltersReebGraph_EXPORTS
+#    ifdef FiltersReebGraph_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSREEBGRAPH_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,20 @@
 
 #ifndef VTKFILTERSREEBGRAPH_DEPRECATED
 #  define VTKFILTERSREEBGRAPH_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSREEBGRAPH_DEPRECATED_EXPORT VTKFILTERSREEBGRAPH_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSREEBGRAPH_DEPRECATED_NO_EXPORT VTKFILTERSREEBGRAPH_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSREEBGRAPH_NO_DEPRECATED
+#ifndef VTKFILTERSREEBGRAPH_DEPRECATED_EXPORT
+#  define VTKFILTERSREEBGRAPH_DEPRECATED_EXPORT VTKFILTERSREEBGRAPH_EXPORT VTKFILTERSREEBGRAPH_DEPRECATED
 #endif
 
-
-
+#ifndef VTKFILTERSREEBGRAPH_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSREEBGRAPH_DEPRECATED_NO_EXPORT VTKFILTERSREEBGRAPH_NO_EXPORT VTKFILTERSREEBGRAPH_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSREEBGRAPH_NO_DEPRECATED
+#    define VTKFILTERSREEBGRAPH_NO_DEPRECATED
+#  endif
+#endif
+
+#endif /* VTKFILTERSREEBGRAPH_EXPORT_H */
